==> org.eclipse.incquery.uml.source_1.0.0.201504031717.jar: org/eclipse/incquery/uml/derivedfeatures/util/VertexIncomingQuerySpecification.java <==
package org.eclipse.incquery.uml.derivedfeatures.util;

import com.google.common.collect.Sets;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import org.eclipse.incquery.runtime.api.IncQueryEngine;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFPQuery;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFQuerySpecification;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.runtime.matchers.psystem.PBody;
import org.eclipse.incquery.runtime.matchers.psystem.PVariable;
import org.eclipse.incquery.runtime.matchers.psystem.annotations.PAnnotation;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.Equality;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.ExportedParameter;
import org.eclipse.incquery.runtime.matchers.psystem.basicenumerables.TypeBinary;
import org.eclipse.incquery.runtime.matchers.psystem.basicenumerables.TypeUnary;
import org.eclipse.incquery.runtime.matchers.psystem.queries.PParameter;
import org.eclipse.incquery.runtime.matchers.psystem.queries.QueryInitializationException;
import org.eclipse.incquery.uml.derivedfeatures.VertexIncomingMatch;
import org.eclipse.incquery.uml.derivedfeatures.VertexIncomingMatcher;

/**
 * A pattern-specific query specification that can instantiate VertexIncomingMatcher in a type-safe way.
 * 
 * @see VertexIncomingMatcher
 * @see VertexIncomingMatch
 * 
 */
@SuppressWarnings("all")
public final class VertexIncomingQuerySpecification extends BaseGeneratedEMFQuerySpecification<VertexIncomingMatcher> {
  private VertexIncomingQuerySpecification() {
    super(GeneratedPQuery.INSTANCE);
  }
  
  /**
   * @return the singleton instance of the query specification
   * @throws IncQueryException if the pattern definition could not be loaded
   * 
   */
  public static VertexIncomingQuerySpecification instance() throws IncQueryException {
    try{
    	return LazyHolder.INSTANCE;
    } catch (ExceptionInInitializerError err) {
    	throw processInitializerError(err);
    }
  }
  
  @Override
  protected VertexIncomingMatcher instantiate(final IncQueryEngine engine) throws IncQueryException {
    return VertexIncomingMatcher.on(engine);
  }
  
  @Override
  public VertexIncomingMatch newEmptyMatch() {
    return VertexIncomingMatch.newEmptyMatch();
  }
  
  @Override
  public VertexIncomingMatch newMatch(final Object... parameters) {
    return VertexIncomingMatch.newMatch((org.eclipse.uml2.uml.Vertex) parameters[0], (org.eclipse.uml2.uml.Transition) parameters[1]);
  }
  
  private static class LazyHolder {
    private final static VertexIncomingQuerySpecification INSTANCE = make();
    
    public static VertexIncomingQuerySpecification make() {
      return new VertexIncomingQuerySpecification();					
    }
  }
  
  private static class GeneratedPQuery extends BaseGeneratedEMFPQuery {
    private final static VertexIncomingQuerySpecification.GeneratedPQuery INSTANCE = new GeneratedPQuery();
    
    @Override
    public String getFullyQualifiedName() {
      return "org.eclipse.incquery.uml.derivedfeatures.vertexIncoming";
    }
    
    @Override
    public List<String> getParameterNames() {
      return Arrays.asList("self","temp1");
    }
    
    @Override
    public List<PParameter> getParameters() {
      return Arrays.asList(new PParameter("self", "org.eclipse.uml2.uml.Vertex"),new PParameter("temp1", "org.eclipse.uml2.uml.Transition"));
    }
    
    @Override
    public Set<PBody> doGetContainedBodies() throws QueryInitializationException {
      Set<PBody> bodies = Sets.newLinkedHashSet();
      try {
      {
      	PBody body = new PBody(this);
      	PVariable var_self = body.getOrCreateVariableByName("self");
      	PVariable var_temp1 = body.getOrCreateVariableByName("temp1");
      	PVariable var_vertex = body.getOrCreateVariableByName("vertex");
      	PVariable var__virtual_0_ = body.getOrCreateVariableByName(".virtual{0}");
      	PVariable var_transition = body.getOrCreateVariableByName("transition");
      	body.setExportedParameters(Arrays.<ExportedParameter>asList(
      		new ExportedParameter(body, var_self, "self"),
      				
      		new ExportedParameter(body, var_temp1, "temp1")
      	));
      	new TypeUnary(body, var_self, getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Vertex"), "http://www.eclipse.org/uml2/5.0.0/UML/Vertex");
      	new TypeUnary(body, var_temp1, getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition"), "http://www.eclipse.org/uml2/5.0.0/UML/Transition");
      	new TypeUnary(body, var_temp1, getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition"), "http://www.eclipse.org/uml2/5.0.0/UML/Transition");
      	new TypeBinary(body, CONTEXT, var_temp1, var__virtual_0_, getFeatureLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition", "target"), "http://www.eclipse.org/uml2/5.0.0/UML/Transition.target");
      	new Equality(body, var__virtual_0_, var_vertex);
      	new Equality(body, var_vertex, var_self);
      	new TypeUnary(body, var_transition, getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition"), "http://www.eclipse.org/uml2/5.0.0/UML/Transition");
      	new Equality(body, var_temp1, var_transition);
      	bodies.add(body);
      }
      	{
      	PAnnotation annotation = new PAnnotation("Surrogate");
      	annotation.addAttribute("feature", "incoming");
      	addAnnotation(annotation);
      }
      	// to silence compiler error
      	if (false) throw new IncQueryException("Never", "happens");
      } catch (IncQueryException ex) {
      	throw processDependencyException(ex);
      }
      return bodies;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.0.0.201504211455.jar: org/eclipse/incquery/uml/derivedfeatures/util/VertexIncomingQuerySpecification.java <==
package org.eclipse.incquery.uml.derivedfeatures.util;

import com.google.common.collect.Sets;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.incquery.runtime.api.IncQueryEngine;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFPQuery;
import org.eclipse.incquery.runtime.api.impl.BaseGeneratedEMFQuerySpecification;
import org.eclipse.incquery.runtime.emf.types.EClassTransitiveInstancesKey;
import org.eclipse.incquery.runtime.emf.types.EStructuralFeatureInstancesKey;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.runtime.matchers.psystem.PBody;
import org.eclipse.incquery.runtime.matchers.psystem.PVariable;
import org.eclipse.incquery.runtime.matchers.psystem.annotations.PAnnotation;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.Equality;
import org.eclipse.incquery.runtime.matchers.psystem.basicdeferred.ExportedParameter;
import org.eclipse.incquery.runtime.matchers.psystem.basicenumerables.TypeConstraint;
import org.eclipse.incquery.runtime.matchers.psystem.queries.PParameter;
import org.eclipse.incquery.runtime.matchers.psystem.queries.QueryInitializationException;
import org.eclipse.incquery.runtime.matchers.tuple.FlatTuple;
import org.eclipse.incquery.uml.derivedfeatures.VertexIncomingMatch;
import org.eclipse.incquery.uml.derivedfeatures.VertexIncomingMatcher;

/**
 * A pattern-specific query specification that can instantiate VertexIncomingMatcher in a type-safe way.
 * 
 * @see VertexIncomingMatcher
 * @see VertexIncomingMatch
 * 
 */
@SuppressWarnings("all")
public final class VertexIncomingQuerySpecification extends BaseGeneratedEMFQuerySpecification<VertexIncomingMatcher> {
  private VertexIncomingQuerySpecification() {
    super(GeneratedPQuery.INSTANCE);
  }
  
  /**
   * @return the singleton instance of the query specification
   * @throws IncQueryException if the pattern definition could not be loaded
   * 
   */
  public static VertexIncomingQuerySpecification instance() throws IncQueryException {
    try{
    	return LazyHolder.INSTANCE;
    } catch (ExceptionInInitializerError err) {
    	throw processInitializerError(err);
    }
  }
  
  @Override
  protected VertexIncomingMatcher instantiate(final IncQueryEngine engine) throws IncQueryException {
    return VertexIncomingMatcher.on(engine);
  }
  
  @Override
  public VertexIncomingMatch newEmptyMatch() {
    return VertexIncomingMatch.newEmptyMatch();
  }
  
  @Override
  public VertexIncomingMatch newMatch(final Object... parameters) {
    return VertexIncomingMatch.newMatch((org.eclipse.uml2.uml.Vertex) parameters[0], (org.eclipse.uml2.uml.Transition) parameters[1]);
  }
  
  private static class LazyHolder {
    private final static VertexIncomingQuerySpecification INSTANCE = make();
    
    public static VertexIncomingQuerySpecification make() {
      return new VertexIncomingQuerySpecification();					
    }
  }
  
  private static class GeneratedPQuery extends BaseGeneratedEMFPQuery {
    private final static VertexIncomingQuerySpecification.GeneratedPQuery INSTANCE = new GeneratedPQuery();
    
    @Override
    public String getFullyQualifiedName() {
      return "org.eclipse.incquery.uml.derivedfeatures.vertexIncoming";
    }
    
    @Override
    public List<String> getParameterNames() {
      return Arrays.asList("self","temp1");
    }
    
    @Override
    public List<PParameter> getParameters() {
      return Arrays.asList(new PParameter("self", "org.eclipse.uml2.uml.Vertex"),new PParameter("temp1", "org.eclipse.uml2.uml.Transition"));
    }
    
    @Override
    public Set<PBody> doGetContainedBodies() throws QueryInitializationException {
      Set<PBody> bodies = Sets.newLinkedHashSet();
      try {
      {
      	PBody body = new PBody(this);
      	PVariable var_self = body.getOrCreateVariableByName("self");
      	PVariable var_temp1 = body.getOrCreateVariableByName("temp1");
      	PVariable var_vertex = body.getOrCreateVariableByName("vertex");
      	PVariable var__virtual_0_ = body.getOrCreateVariableByName(".virtual{0}");
      	PVariable var_transition = body.getOrCreateVariableByName("transition");
      	body.setExportedParameters(Arrays.<ExportedParameter>asList(
      		new ExportedParameter(body, var_self, "self"),
      				
      		new ExportedParameter(body, var_temp1, "temp1")
      	));
      	new TypeConstraint(body, new FlatTuple(var_self), new EClassTransitiveInstancesKey((EClass)getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Vertex")));
      	new TypeConstraint(body, new FlatTuple(var_temp1), new EClassTransitiveInstancesKey((EClass)getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition")));
      	new TypeConstraint(body, new FlatTuple(var_temp1), new EClassTransitiveInstancesKey((EClass)getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition")));
      	new TypeConstraint(body, new FlatTuple(var_temp1, var__virtual_0_), new EStructuralFeatureInstancesKey(getFeatureLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition", "target")));
      	new Equality(body, var__virtual_0_, var_vertex);
      	new Equality(body, var_vertex, var_self);
      	new TypeConstraint(body, new FlatTuple(var_transition), new EClassTransitiveInstancesKey((EClass)getClassifierLiteral("http://www.eclipse.org/uml2/5.0.0/UML", "Transition")));
      	new Equality(body, var_temp1, var_transition);
      	bodies.add(body);
      }
      	{
      	PAnnotation annotation = new PAnnotation("Surrogate");
      	annotation.addAttribute("feature", "incoming");
      	addAnnotation(annotation);
      }
      	// to silence compiler error
      	if (false) throw new IncQueryException("Never", "happens");
      } catch (IncQueryException ex) {
      	throw processDependencyException(ex);
      }
      return bodies;
    }
  }
}
